/* Réception des capteurs d'une MiniWi Interface-Z
 * configuree sur le port destinataire 8887 et un en-tete de message OSC /CA.
 * Un test est fait sur cet en-tete pour cibler les donnees envoyees par MiniWi. 
 * La technique est aussi utile en cas de plusieurs MiniWis.
 */
/* Receiving data from sensors on a MiniWi Interface-Z,
 * configured on destination UDP port 8887 and OSC message header set on /CA.
 * A test is ran on this header to target the data sent by a MiniWi.
 * Usefull too if several MiniWis are used at the same time.
 */
 
// Importer la librairie oscP5 / Import oscP5 library.
// netP5 est indispensable aussi / net P5 is imported too.
import oscP5.*;
import netP5.*;

// Port reseau UDP, adresse reseau
// Network UDP port, network address
OscP5 oscP5;

// Texte / Text
PFont policeperso, policetitre;

void setup() {
  // Parametres graphiques
  // Visual elements
  size(400, 600);
  background(0);
  noStroke();
  /* Ouverture d'un port pour la reception de messages de la MiniWi. 
   Un numero de port sert a recevoir des messages provenant de l'exterieur. 
   */
  /* Opening a port in order to receive messages from the MiniWi board. 
   A port number is used to receive messages from the outside. 
   */   
  oscP5 = new OscP5(this, 8888);
  policeperso = loadFont("Calibri-28.vlw");
  policetitre = loadFont("Duvall-36.vlw");
}

/**************************************
 Reception des donnees des capteurs
 Receiving sensors data
 **************************************/

int boutons ;
// Tableaux contenant les 4 capteurs analogiques
// et les 5 capteurs boutons d'une MiniWi.
// Arrays containing the 4 analog sensors
// and the 5 switch sensors on a MiniWi.
int[] capteurs = new int[4];
int[] boutons_tries = new int[5];

// Gere les messages arrivant de la MiniWi
// Manage messages from the MiniWi card
void oscEvent(OscMessage message_miniwi) {
  // En-tete de message OSC specifique configure sur la MiniWi utilisee.
  // Specific OSC message header set up the used MiniWi.
  if (message_miniwi.checkAddrPattern("/CA")==true) {
    // Tri des 4 capteurs analogiques
    // Separating the 4 analog sensors
    capteurs[0] = message_miniwi.get(0).intValue();
    capteurs[1] = message_miniwi.get(1).intValue();
    capteurs[2] = message_miniwi.get(2).intValue();
    capteurs[3] = message_miniwi.get(3).intValue();
    boutons = message_miniwi.get(4).intValue();
    // Identification des 5 boutons individuels
    // Identifying the 5 switches
    boutons_tries[0] = (boutons&16)>>4;
    boutons_tries[1] = (boutons&8)>>3;
    boutons_tries[2] = (boutons&4)>>2;
    boutons_tries[3] = (boutons&2)>>1;
    boutons_tries[4] = boutons&1;
  }
}

/**************************************
 Affichage des donnees des capteurs
 Displaying sensors data
 **************************************/
 
void draw() {  
  background(0);
  fill(70, 190, 220);
  textFont(policetitre, 36);
  text("MiniWi Interface-Z ", 16, 48);
  textFont(policeperso, 28);
  /* Affichage des valeurs des capteurs analogiques
   Les valeurs sont affichées sur 409 niveaux et non 4096 pas, pour passer dans l'écran
   */
  /* Displaying analog sensors values.
   Values are shown on 409 steps, not 4096 steps, to appear on a screen.
   */   
  // Affichage de 4 Blocs bleus, fond des sliders. / Blue sliders background
  fill(50, 100, 200);
  for (int i=0; i<4; i++) {
    rect(60+(i*30), 80, 20, 409);
    text(i+1, 64+(i*30), 515);
    text((i+1)+" : ", 200, 365 + (i*50));
  }
  // Affichage devant d'un bloc clair dont la hauteur
  // depend de la valeur du capteur
  // Light blue rectangle in front, heigth depending on the sensor's value
  fill(70, 190, 220);
  for (int i=0; i<4; i++) {
    rect(60+(i*30), 489-int(capteurs[i]/10), 20, int(capteurs[i]/10));
    // Ecart en x constant, depart du coin en y variable, largeur x constante, hauteur y variable.
    text(capteurs[i], 250, 365 + (i*50));
  }

  /* Affichage des valeurs des interrupteurs
   Les valeurs sont affichées en On/Off.
   */
  /* Displaying switches states, On/Off.
   */   
  // Affichage de 5 carres bleus, au fond. / 5 blue square in the back.
  fill(50, 100, 200);
  for (int i=0; i<5; i++) {
    rect(200, 80+(i*50), 30, 30);
    text("Bouton "+(i+1), 250, 104+(i*50));
  }
  // Affichage devant d'un bloc clair si le bouton est actif
  // Light square in the front if switch is On.
  fill(70, 190, 220);
  for (int i=0; i<5; i++) {
    rect(200, 80+(i*50), 30*boutons_tries[i], 30*boutons_tries[i]);
    // Ecart en y constant, depart du coin en x variable.
  }
}